==> oarepo_oai_pmh_harvester-4.1.1.tar.gz: oarepo_oai_pmh_harvester-4.1.1/oarepo_oaipmh_harvester/oai_run/ext.py <==
import re
from functools import cached_property

from oarepo_oaipmh_harvester.oai_run import config


class Oai_runExt:
    def __init__(self, app=None):
        if app:
            self.init_app(app)

    def init_app(self, app):
        """Flask application initialization."""

        self.init_config(app)
        if not self.is_inherited():
            self.register_flask_extension(app)

    def register_flask_extension(self, app):
        app.extensions["oarepo_oaipmh_harvester.oai_run"] = self

    def init_config(self, app):
        """Initialize configuration."""
        for identifier in dir(config):
            if re.match("^[A-Z_0-9]*$", identifier) and not identifier.startswith("_"):
                if isinstance(app.config.get(identifier), list):
                    app.config[identifier] += getattr(config, identifier)
                elif isinstance(app.config.get(identifier), dict):
                    app.config[identifier].update(getattr(config, identifier))
                else:
                    app.config.setdefault(identifier, getattr(config, identifier))

    def is_inherited(self):
        from importlib_metadata import entry_points

        ext_class = type(self)
        for ep in entry_points(group="invenio_base.apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        for ep in entry_points(group="invenio_base.api_apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        return False

    @cached_property
    def service_records(self):
        return config.OAI_RUN_RECORD_SERVICE_CLASS(
            config=config.OAI_RUN_RECORD_SERVICE_CONFIG(),
        )

    @cached_property
    def resource_records(self):
        return config.OAI_RUN_RECORD_RESOURCE_CLASS(
            service=self.service_records,
            config=config.OAI_RUN_RECORD_RESOURCE_CONFIG(),
        )

==> oarepo_oai_pmh_harvester-4.1.7.tar.gz: oarepo_oai_pmh_harvester-4.1.7/oarepo_oaipmh_harvester/oai_run/ext.py <==
import re
from functools import cached_property

from oarepo_oaipmh_harvester.oai_run import config


class Oai_runExt:

    def __init__(self, app=None):

        if app:
            self.init_app(app)

    def init_app(self, app):
        """Flask application initialization."""

        self.init_config(app)
        if not self.is_inherited():
            self.register_flask_extension(app)

    def register_flask_extension(self, app):

        app.extensions["oarepo_oaipmh_harvester.oai_run"] = self

    def init_config(self, app):
        """Initialize configuration."""
        for identifier in dir(config):
            if re.match("^[A-Z_0-9]*$", identifier) and not identifier.startswith("_"):
                if isinstance(app.config.get(identifier), list):
                    app.config[identifier] += getattr(config, identifier)
                elif isinstance(app.config.get(identifier), dict):
                    for k, v in getattr(config, identifier).items():
                        if k not in app.config[identifier]:
                            app.config[identifier][k] = v
                else:
                    app.config.setdefault(identifier, getattr(config, identifier))

    def is_inherited(self):
        from importlib_metadata import entry_points

        ext_class = type(self)
        for ep in entry_points(group="invenio_base.apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        for ep in entry_points(group="invenio_base.api_apps"):
            loaded = ep.load()
            if loaded is not ext_class and issubclass(ext_class, loaded):
                return True
        return False

    @cached_property
    def service_records(self):
        return config.OAI_RUN_RECORD_SERVICE_CLASS(
            config=config.OAI_RUN_RECORD_SERVICE_CONFIG(),
        )

    @cached_property
    def resource_records(self):
        return config.OAI_RUN_RECORD_RESOURCE_CLASS(
            service=self.service_records,
            config=config.OAI_RUN_RECORD_RESOURCE_CONFIG(),
        )
